% find the binarized pattern
function [bin] = TIbin(emesh, stain, verbose)


    if nargin < 3,
        verbose = 0;
    end

    j_e_mrf = exist('JTImrf2');
    if j_e_mrf == 8,
    	jmrf = JTImrf2(fully_connected(emesh));
    else
        error('Java MRF not found - check your classpath!\n');
    end

    if verbose > 0, fprintf('Calculating binarized patterns... '); end

    % datapoints
    dp = size(stain,1);
    dlen = size(stain,2);
        
    bpat = zeros(dp, dlen);
    for i=1:dlen, 
        jmrf.oneMesh(2, stain(:,i), 2); 
        bpat(:,i) = jmrf.getLabels(1); 
    end

    bin = zeros(dp, dlen);
    for i=1:dlen, 
        if mean(stain(bpat(:,i) == 1,i)) < mean(stain(bpat(:,i) == 2,i)),
            bin(bpat(:,i) == 1,i) = 1;
        else
            bin(bpat(:,i) == 2,i) = 1;
        end
    end

    if verbose > 0, fprintf('done\n'); end

end


% from find_restricted
function [t_conn] = fully_connected(emesh)

    for i=1:length(emesh.t)
        tnfr{i} = [];   
        tnf{i} = []; 
        for j=1:size(emesh.t,2)       
            [prow, pcol] = find(emesh.t==emesh.t(i,j));
            tnfr{i} = [tnfr{i}, prow(prow ~= i)'];
        end
        for j=1:length(emesh.tn{i})
           if length(find(tnfr{i} == emesh.tn{i}(j))) > 1,
            tnf{i} = [tnf{i}, emesh.tn{i}(j)];
          end
        end
    end

    t_conn=zeros(311,311);
    for i=1:length(tnf), 
        for j=1:length(tnf{i}), 
            t_conn(i,tnf{i}(j)) = 1; 
            t_conn(i,i) = 1; 
        end;
    end

    t_conn = logical(t_conn);
end
