function TIgen_exe(dirname, effname, lmn, varargin)
% Batch segmentation of the embryos in a directory
% Version 2, variable arguments (similar to do_meshes.m)
%
% TIgen(dirname, effname, lmn, varagin)
%                            
% TIgen('/Users/erwin/Desktop/bill-2008101', 'bill-2008101.eff', 0, 'verbose','dic');
%
% Output: 
% eff file <effname>
% 
% Input:
% dirname: name of directory
% outfile: name of the output file
% lmn: cornerpoint identifier (for fembryo), 0 to use default
%                           cornerpoint identifier:
%                           0=16 cornerpoints (default)
%                           1=8  cornerpoints
%                           2=16 cornerpoints
%                           3=4  cornerpoints (only interactive)
% varargin:
%   'startembryo', <number>: start at embryo number
%   'embryos', <list>: do only embryos in that list (1D vector), overrides startembryo
%   'dic': use DIC correction
%   'gray': images are grayscale, DIC correction won't work
%   'eff', <filename>: write to EFF file
%   'verbose': verbose
%   'interactive': interactive segmentation, mark points with mouse on
%                  image
%

ct_vars = 0;

if exist('dirname', 'var'), ct_vars = ct_vars+1; end
if exist('effname', 'var'), ct_vars = ct_vars+1; end
if exist('lmn','var'), ct_vars = ct_vars+1; end

if ct_vars < 2,
    if isdeployed,
        fprintf('TIgen_exe\n');
        fprintf('Matlab TIgen deployment\n');
        fprintf('(c) Erwin Frise 2010, See Nat. MSB 2010 publication for details\n\n');
        fprintf('./runTIgen_exe <MCR installation> <dirname> <effname> <lmn> ...\n');
        fprintf('e.g. ./run_TIgen_exe.sh /opt/MCR/v717 ./dirlink ./ti.eff 0 verbose)\n');
    else
        fprintf('TIgen_exe(dirname, effname, lmn, vararg)\n');
        fprintf('e.g. TIgen_exe(''dirlink'', ''ti.eff'', 0, ''verbose'')');
    end
    fprintf('For deployment, option ''dic'' is added automatically\n');
    fprintf('Noteworthy additional arguments (...):\n');
    fprintf('  verbose     verbose output\n');
    fprintf('  start <no>  start at embryo number <no>, must be >= 1\n');
    fprintf('  end <no>    stop at embryo number <no>\n');
    fprintf('  interactive launches gui for interactive segmentation\n');
    return;
end

if isdeployed,
    lmn = str2num(lmn);
end

fprintf('Args: dirname = %s, effname = %s, lmn = %d\n', dirname, effname, lmn);

ti.t = [
[ 170, 171, 163]
[ 170, 171, 176]
[  10,   4,   3]
[  10,   3,   9]
[ 174, 180, 175]
[ 172, 176, 177]
[ 172, 171, 176]
[ 160, 168, 151]
[ 119, 129, 118]
[ 128, 129, 140]
[ 128, 139, 140]
[ 128, 138, 139]
[ 128, 138, 127]
[ 149, 158, 157]
[ 130, 129, 140]
[ 130, 141, 140]
[ 130, 141, 142]
[ 130, 119, 129]
[ 130, 142, 131]
[ 130, 119, 131]
[   7,   8,  14]
[  18,  10,   9]
[  44,  34,  45]
[  16,  18,   9]
[ 167, 174, 158]
[ 167, 174, 175]
[ 178, 179, 180]
[ 178, 174, 180]
[ 178, 179, 177]
[ 178, 172, 177]
[ 169, 160, 168]
[ 169, 167, 175]
[ 169, 167, 168]
[ 107,  97,  96]
[ 107,  95,  96]
[ 120, 119, 131]
[ 148, 138, 139]
[ 148, 149, 157]
[ 148, 149, 139]
[ 125, 124, 113]
[ 150, 149, 139]
[ 150, 139, 140]
[ 150, 141, 151]
[ 150, 141, 140]
[ 159, 149, 158]
[ 159, 167, 158]
[ 159, 167, 168]
[ 159, 150, 149]
[ 159, 168, 151]
[ 159, 150, 151]
[   6,   8,   2]
[   6,   7,   8]
[   6,   2,   1]
[  13,  21,   7]
[  13,  15,  14]
[  13,   7,  14]
[  19,  18,  27]
[  65,  54,  64]
[ 152, 141, 142]
[  98,  99,  87]
[  85,  97,  96]
[  85,  98,  97]
[  84,  85,  96]
[  84,  85,  74]
[  30,  21,  29]
[ 117, 116, 127]
[ 117, 129, 118]
[ 117, 128, 127]
[ 117, 128, 129]
[  56,  67,  57]
[  56,  55,  67]
[  56,  44,  45]
[  56,  44,  55]
[  48,  58,  47]
[  28,  19,  29]
[  28,  19,  27]
[ 100, 112, 111]
[ 122, 134, 133]
[ 123, 124, 113]
[ 123, 134, 124]
[ 123, 112, 113]
[ 123, 112, 111]
[ 123, 122, 111]
[ 123, 122, 134]
[ 154, 162, 153]
[  17,  18,  27]
[  17,  16,  18]
[  17,  26,  27]
[  17,  16,  25]
[  17,  26,  25]
[ 135, 134, 124]
[  24,  26,  25]
[ 173, 174, 158]
[ 173, 178, 174]
[ 173, 178, 172]
[ 106, 107, 118]
[ 106, 107,  95]
[ 106, 117, 118]
[ 106, 117, 116]
[ 106, 116, 105]
[ 106,  95, 105]
[ 108, 107,  97]
[ 108, 120, 119]
[ 108, 119, 118]
[ 108, 107, 118]
[ 137, 148, 138]
[ 104, 116, 105]
[   5,   4,   1]
[   5,   6,   1]
[   5,  10,   4]
[  20,  21,  29]
[  20,  19,  29]
[  32,  33,  23]
[  75,  65,  64]
[ 132, 142, 131]
[ 132, 152, 142]
[ 161, 160, 151]
[ 161, 141, 151]
[ 161, 152, 141]
[ 109,  98,  97]
[ 109, 108,  97]
[ 109, 108, 120]
[ 109,  98,  99]
[  63,  75,  64]
[  63,  75,  74]
[  52,  63,  64]
[  52,  63,  62]
[  61,  50,  60]
[  61,  50,  62]
[  31,  30,  41]
[  31,  32,  41]
[  31,  13,  21]
[  31,  30,  21]
[  94,  95, 105]
[  83,  95,  96]
[  83,  84,  96]
[  83,  94,  95]
[  83,  94,  82]
[  71,  61,  60]
[  59,  48,  58]
[  59,  48,  60]
[  59,  71,  60]
[  66,  55,  67]
[ 145, 143, 153]
[ 145, 154, 153]
[ 145, 135, 146]
[ 164, 162, 163]
[ 164, 154, 162]
[ 164, 171, 163]
[  46,  58,  47]
[  46,  36,  47]
[  46,  36,  45]
[  46,  58,  57]
[  46,  56,  45]
[  46,  56,  57]
[  35,  34,  45]
[  35,  36,  45]
[  35,  24,  34]
[  35,  36,  26]
[  35,  24,  26]
[  37,  26,  27]
[  37,  36,  26]
[  37,  28,  27]
[  37,  36,  47]
[ 126, 138, 127]
[ 126, 137, 138]
[ 115, 104, 116]
[ 115, 126, 125]
[ 115, 116, 127]
[ 115, 126, 127]
[ 114, 125, 113]
[ 114, 115, 125]
[ 114, 115, 104]
[ 101, 100, 112]
[ 101,  89, 100]
[  12,  21,   7]
[  12,  20,  21]
[  12,   6,   7]
[  12,   5,   6]
[  76,  75,  65]
[ 121, 120, 131]
[ 121, 132, 131]
[  42,  32,  33]
[  42,  43,  33]
[  42,  32,  41]
[  40,  30,  41]
[  73,  63,  62]
[  73,  61,  62]
[  73,  84,  74]
[  73,  63,  74]
[  22,  32,  23]
[  22,  31,  32]
[  22,  15,  23]
[  22,  13,  15]
[  22,  31,  13]
[  93, 104, 105]
[  93,  94, 105]
[  72,  71,  61]
[  72,  73,  61]
[  72,  83,  82]
[  72,  71,  82]
[  72,  83,  84]
[  72,  73,  84]
[ 144, 145, 143]
[ 144, 145, 135]
[ 144, 143, 133]
[ 144, 134, 133]
[ 144, 135, 134]
[ 166, 158, 157]
[ 166, 173, 158]
[ 155, 164, 154]
[ 155, 145, 146]
[ 155, 145, 154]
[  38,  37,  47]
[  38,  37,  28]
[  38,  48,  47]
[ 136, 126, 137]
[ 136, 135, 146]
[ 136, 137, 146]
[ 136, 126, 125]
[ 136, 125, 124]
[ 136, 135, 124]
[ 103, 114, 104]
[ 103,  93, 104]
[  11,   5,  10]
[  11,  12,   5]
[  11,  12,  20]
[  11,  20,  19]
[  11,  18,  10]
[  11,  19,  18]
[  86,  76,  75]
[  86,  85,  98]
[  86,  98,  87]
[  86,  76,  87]
[  86,  85,  74]
[  86,  75,  74]
[ 110, 109,  99]
[ 110, 109, 120]
[ 110, 121, 120]
[  53,  42,  43]
[  53,  42,  52]
[  53,  43,  54]
[  53,  54,  64]
[  53,  52,  64]
[  51,  42,  41]
[  51,  42,  52]
[  51,  40,  41]
[  51,  40,  50]
[  51,  50,  62]
[  51,  52,  62]
[  39,  30,  29]
[  39,  40,  30]
[  39,  28,  29]
[  39,  38,  28]
[  81,  94,  82]
[  81,  93,  94]
[ 165, 164, 171]
[ 165, 166, 173]
[ 165, 172, 171]
[ 165, 173, 172]
[ 147, 155, 146]
[ 147, 137, 146]
[ 147, 148, 157]
[ 147, 137, 148]
[ 102, 114, 113]
[ 102, 103, 114]
[ 102, 112, 113]
[ 102, 101, 112]
[  49,  38,  48]
[  49,  39,  38]
[  49,  48,  60]
[  49,  50,  60]
[  49,  40,  50]
[  49,  39,  40]
[  70,  81,  82]
[  70,  71,  82]
[  70,  59,  71]
[ 156, 155, 164]
[ 156, 165, 164]
[ 156, 165, 166]
[ 156, 147, 155]
[ 156, 166, 157]
[ 156, 147, 157]
[  78,  66,  67]
[  78,  77,  66]
[  92, 103,  93]
[  92,  81,  93]
[  69,  59,  58]
[  69,  70,  59]
[  69,  58,  57]
[  90,  77,  88]
[  90,  78,  77]
[  90,  89,  88]
[  90, 101,  89]
[  90,  78,  79]
[  91,  92,  79]
[  91, 102, 101]
[  91, 102, 103]
[  91,  92, 103]
[  91,  90, 101]
[  91,  90,  79]
[  80,  92,  79]
[  80,  92,  81]
[  80,  70,  81]
[  80,  69,  70]
[  68,  80,  79]
[  68,  67,  57]
[  68,  69,  57]
[  68,  80,  69]
[  68,  78,  67]
[  68,  78,  79]];

ti.p = [
[        -4502999233408471/1125899906842624, -4706300423111087/144115188075855872]
[         -2214227815328609/562949953421312,    1638524114672369/4503599627370496]
[        -8343437844077321/2251799813685248,    -848405980875375/1125899906842624]
[        -4400339533044325/1125899906842624,   -3835458982578819/9007199254740992]
[        -8040478116634605/2251799813685248,  -5970096369539301/36028797018963968]
[        -8115510694142207/2251799813685248,   8806723038062215/36028797018963968]
[          -467856572599405/140737488355328,    2521761793596059/4503599627370496]
[        -8409120983190227/2251799813685248,    1613716417205813/2251799813685248]
[        -3849119724427125/1125899906842624,   -2338094725633723/2251799813685248]
[          -480741052223807/140737488355328,   -5101988023664029/9007199254740992]
[         -1774981246706305/562949953421312,    -669646341113961/2251799813685248]
[        -7261094925857455/2251799813685248,   2635023807531985/18014398509481984]
[        -6849145379432169/2251799813685248,    3643388736689695/4503599627370496]
[        -3883261846705135/1125899906842624,    2280939944911611/2251799813685248]
[        -3503008910201991/1125899906842624,    5660861477466741/4503599627370496]
[        -3494717304429609/1125899906842624,   -5681323988329959/4503599627370496]
[        -3117519547275285/1125899906842624,   -1189833883720725/1125899906842624]
[        -3427545685458735/1125899906842624,   -3434157045468821/4503599627370496]
[         -1552762150248451/562949953421312,   -3594149241596589/9007199254740992]
[        -6464366533237601/2251799813685248,  3596265506319441/576460752303423488]
[        -3208419457416023/1125899906842624,    3779713060789955/9007199254740992]
[        -6189903739674415/2251799813685248,    4863356125257217/4503599627370496]
[        -6103610958508887/2251799813685248,    1655965950712781/1125899906842624]
[         -1328024862758687/562949953421312,   -7274011121486327/4503599627370496]
[          -765525002141903/281474976710656,   -1651208128796503/1125899906842624]
[          -665459547150981/281474976710656,   -5098286883464937/4503599627370496]
[        -5752562749035399/2251799813685248,   -6560737721051063/9007199254740992]
[        -5255844199450037/2251799813685248,   -3036896296143169/9007199254740992]
[        -5680689447617103/2251799813685248,  5542712213737687/144115188075855872]
[        -2671042437427441/1125899906842624,    3707545483583585/9007199254740992]
[        -5794628828622935/2251799813685248,    3372106812754579/4503599627370496]
[        -2658904904918641/1125899906842624,    2681855362461997/2251799813685248]
[        -5220066655037173/2251799813685248,    7340336675461979/4503599627370496]
[        -8736294724277885/4503599627370496,   -3938557063808023/2251799813685248]
[         -1157309613706083/562949953421312,   -1535401623348415/1125899906842624]
[        -8480402185135605/4503599627370496,   -4642632543347595/4503599627370496]
[        -4814036620690677/2251799813685248,   -1631355887865761/2251799813685248]
[        -8595466399163221/4503599627370496,   -3033574209813687/9007199254740992]
[        -4743995360945463/2251799813685248,  6964476609573209/144115188075855872]
[        -8728105542691467/4503599627370496,    1992962879981081/4503599627370496]
[        -4855706200437613/2251799813685248,        57893867893559/70368744177664]
[        -8893891478230141/4503599627370496,      176666472314869/140737488355328]
[        -2185651671690895/1125899906842624,    7875363195435939/4503599627370496]
[        -6920164332242563/4503599627370496,    -1039512128537381/562949953421312]
[          -463337373839649/281474976710656,   -6428292695317409/4503599627370496]
[        -6523763441647497/4503599627370496,   -4832625743768895/4503599627370496]
[        -1885861350482699/1125899906842624,   -6166025174204715/9007199254740992]
[        -6609861100846483/4503599627370496,  -5748702003653737/18014398509481984]
[        -7626383182843839/4503599627370496,   2006738306770583/36028797018963968]
[        -3400483009102859/2251799813685248,   7961830709876375/18014398509481984]
[          -982249795020535/562949953421312,    1886242875395527/2251799813685248]
[        -6718763930647481/4503599627370496,    5139512404504909/4503599627370496]
[        -7472999338171361/4503599627370496,    6669923611996463/4503599627370496]
[        -6748467348189715/4503599627370496,    8351298430136663/4503599627370496]
[        -5117001061531349/4503599627370496,   -4318093139355929/2251799813685248]
[        -1404884876034721/1125899906842624,   -6738595604422125/4503599627370496]
[        -4655130085469095/4503599627370496,   -5073239304316317/4503599627370496]
[          -699731399215863/562949953421312,   -6412224396516959/9007199254740992]
[        -4687672229834931/4503599627370496,  -6154016609729831/18014398509481984]
[        -5701375192039123/4503599627370496,  8027527089897267/144115188075855872]
[        -4772717196705771/4503599627370496,   7501861226240507/18014398509481984]
[        -5770167071547629/4503599627370496,    7073555365374815/9007199254740992]
[        -1179529469043959/1125899906842624,    2607928807346615/2251799813685248]
[        -5566191749026265/4503599627370496,      855439503841475/562949953421312]
[        -4823627892395747/4503599627370496,    4339147147368593/2251799813685248]
[        -6678965371101241/9007199254740992,   -8851079155226277/4503599627370496]
[        -7592025651094485/9007199254740992,   -6974342049512131/4503599627370496]
[        -5593707149981783/9007199254740992,   -2632340790348339/2251799813685248]
[        -3718593573319345/4503599627370496,   -3387365390856275/4503599627370496]
[        -2793647108722145/4503599627370496,   -3367964783999829/9007199254740992]
[        -7519802922033765/9007199254740992,  8320820593410797/288230376151711744]
[        -5646646349531623/9007199254740992,   7354090904071389/18014398509481984]
[        -7559419388809033/9007199254740992,    3559689324355919/4503599627370496]
[          -175474774680941/281474976710656,    2672150118717859/2251799813685248]
[         -928840014018675/1125899906842624,    7047878586854971/4503599627370496]
[          -362239950316905/562949953421312,    8889890539866777/4503599627370496]
[       -6484215601922233/18014398509481984,   -4485328427563551/2251799813685248]
[        -1925897965116447/4503599627370496,   -1783543374461693/1125899906842624]
[       -7441843556669029/36028797018963968,     -336963450088561/281474976710656]
[       -7408954644012263/18014398509481984,   -7066750098544199/9007199254740992]
[       -7417871440354869/36028797018963968,  -7049020028588009/18014398509481984]
[       -7459277680359857/18014398509481984,    888898201552491/72057594037927936]
[         -467438801379855/2251799813685248,     915284984690657/2251799813685248]
[        -3745162884073279/9007199254740992,    1803318620399363/2251799813685248]
[       -7458356800067291/36028797018963968,    1352769902338801/1125899906842624]
[           -58103173093117/140737488355328,    7178263886922781/4503599627370496]
[        -1933189954222011/9007199254740992,        70267373482703/35184372088832]
[   4233091656628951/1180591620717411303424,    -1125899906371471/562949953421312]
[         3242158740183841/9007199254740992,   -4485327853798725/2251799813685248]
[  -5174408457685609/2361183241434822606848,   -3610650954241843/2251799813685248]
[        3720899561767543/18014398509481984,     -673927282214631/562949953421312]
[ -2439806941777101/18889465931478580854784,   -3586802219267653/4503599627370496]
[        3708935392164919/18014398509481984,  -7049023193575839/18014398509481984]
[  1565791482072269/37778931862957161709568, 8471937099186253/1152921504606846976]
[         1869756044740899/9007199254740992,   7322278834592539/18014398509481984]
[  1756319553421311/37778931862957161709568,    7246208950312085/9007199254740992]
[        3729179762878689/18014398509481984,    1352769881911353/1125899906842624]
[ 4484299833422643/151115727451828646838272,    7221338649619585/4503599627370496]
[        7732761301455673/36028797018963968,    4497111902447177/2251799813685248]
[         3339496321792193/4503599627370496,   -2212769467960489/1125899906842624]
[        7703544013701913/18014398509481984,   -7134176559281799/4503599627370496]
[         5593697577631691/9007199254740992,   -5264684692316273/4503599627370496]
[        7408947058060297/18014398509481984,   -7066755183388777/9007199254740992]
[           349205802209691/562949953421312,  -6735936514346343/18014398509481984]
[         1864819601214975/4503599627370496,  7111081817004223/576460752303423488]
[         1411661699004091/2251799813685248,    3677044204491335/9007199254740992]
[         3745163586719861/9007199254740992,    3606636962744147/4503599627370496]
[         2807596660366663/4503599627370496,    2672150014585721/2251799813685248]
[         3718603560591679/9007199254740992,    7178263816380735/4503599627370496]
[         1448959881227439/2251799813685248,      277809079098039/140737488355328]
[         1279252155721629/1125899906842624,   -8636185158197369/4503599627370496]
[         7592013219395987/9007199254740992,     -217948216140689/140737488355328]
[         4655126683733189/4503599627370496,     -634155093485289/562949953421312]
[         7437182843971369/9007199254740992,     -423420945064355/562949953421312]
[         4687671222937405/4503599627370496,   -1538505594828205/4503599627370496]
[           469987654736309/562949953421312,  4160374279544711/144115188075855872]
[         4772717169248291/4503599627370496,    3750929168328927/9007199254740992]
[         7559419791028705/9007199254740992,    7119377801223427/9007199254740992]
[         4718118041256771/4503599627370496,    1303964338334171/1125899906842624]
[         3715360230269693/4503599627370496,    7047878469875347/4503599627370496]
[         4823628007051567/4503599627370496,    8678294278951597/4503599627370496]
[           432510544239733/281474976710656,   -8316096119076897/4503599627370496]
[         2809768209301505/2251799813685248,   -6738595823782169/4503599627370496]
[         6523761153978495/4503599627370496,   -2416313254036779/2251799813685248]
[           174932792576871/140737488355328,   -6412226907165945/9007199254740992]
[         3304930066609827/2251799813685248,  -5748705887578009/18014398509481984]
[         2850687369756891/2251799813685248,   4013747888288529/72057594037927936]
[         6800965824951511/4503599627370496,    1990456986195495/4503599627370496]
[         5770167121456709/4503599627370496,    7073554465161481/9007199254740992]
[         1679691002329293/1125899906842624,    1284878043926933/1125899906842624]
[         5566191844688661/4503599627370496,        53464967994391/35184372088832]
[         6748467412752983/4503599627370496,    8351298417247835/4503599627370496]
[         2184074340512717/1125899906842624,     -984639175057281/562949953421312]
[         3706698271079903/2251799813685248,   -6428292741548451/4503599627370496]
[         2120100180023505/1125899906842624,   -2321316424532363/2251799813685248]
[         7543443986867545/4503599627370496,   -6166026756463923/9007199254740992]
[         8595465614860217/4503599627370496,  -6067151363566505/18014398509481984]
[         7626382733902489/4503599627370496,   1003366148258215/18014398509481984]
[         8728105306970285/4503599627370496,    3985924792735093/9007199254740992]
[         3928999130501839/2251799813685248,    1886242659937757/2251799813685248]
[         8893891445150735/4503599627370496,    5653326945664079/4503599627370496]
[         7472999378524125/4503599627370496,    1667480885628603/1125899906842624]
[          1328025039733061/562949953421312,   -3637005303665459/2251799813685248]
[         4629238087392413/2251799813685248,   -3070803019439211/2251799813685248]
[         5323676145507479/2251799813685248,   -5098286933843833/4503599627370496]
[         4814036171891579/2251799813685248,       -25489940243951/35184372088832]
[         2627921942822223/1125899906842624,   -3036897132783413/9007199254740992]
[         4743995162661091/2251799813685248,  6964460945743043/144115188075855872]
[           667760595697955/281474976710656,     926886225497617/2251799813685248]
[         4855706122233889/2251799813685248,    7410414597804501/9007199254740992]
[         2658904888882361/1125899906842624,      670463829581367/562949953421312]
[         2185651681653769/1125899906842624,      246105099513839/140737488355328]
[           765525054041421/281474976710656,   -6604832129493037/4503599627370496]
[          1558759739781423/562949953421312,   -1189833848139633/1125899906842624]
[           359535156103117/140737488355328,     -102511528659715/140737488355328]
[         6211048441920709/2251799813685248,   -1797074715922247/4503599627370496]
[         5680689292281243/2251799813685248,   2771351040197107/72057594037927936]
[         6416838818292053/2251799813685248,    1889856422122397/4503599627370496]
[           724328594032981/281474976710656,    3372106693439397/4503599627370496]
[           762951367999463/281474976710656,    6623863817669911/4503599627370496]
[         2610033326288853/1125899906842624,    7340336678471967/4503599627370496]
[         6989434835620537/2251799813685248,     -710165463572551/562949953421312]
[         3849119793190983/1125899906842624,   -4676189225754871/4503599627370496]
[         6855091278449195/2251799813685248,   -3434157013603871/4503599627370496]
[         3549962443084069/1125899906842624,  -5357170820498519/18014398509481984]
[           404022902473885/140737488355328,  3596263969817015/576460752303423488]
[         3424572661457429/1125899906842624,    3643388697983445/4503599627370496]
[         6189903705257461/2251799813685248,    2431678040435183/2251799813685248]
[         3503008899649135/1125899906842624,    1415215376934983/1125899906842624]
[         8343437944542187/2251799813685248,   -6787247356780641/9007199254740992]
[         7691856810639461/2251799813685248,   -5101987929013121/9007199254740992]
[         4020239039804903/1125899906842624,    -746262037727449/4503599627370496]
[         7261094877387633/2251799813685248,     658755920910119/4503599627370496]
[         7485705105520585/2251799813685248,    5043523591152917/9007199254740992]
[          1941630915800237/562949953421312,    4561879941431739/4503599627370496]
[           550042443982217/140737488355328,  -7670917274029985/18014398509481984]
[         9005998468985603/2251799813685248, -4706296153388351/144115188075855872]
[          1014438833205245/281474976710656,   8806723345350677/36028797018963968]
[          1107113905191113/281474976710656,    3277048446093151/9007199254740992]
[         8409120953590065/2251799813685248,    6454865820600637/9007199254740992]    
];


TIgen(dirname, ti, lmn, 'dic', 'eff', effname, varargin{:});

end